@@ -44,8 +44,13 @@ steady.2D    <- function (y, time = 0, func, parms = NULL, nspec = NULL,
     if (is.null(jactype))
       jactype <- "2D"
     # Note: stodes expects rev(dimens)..
+    if (jactype == "2D")
      out <- stodes(y=y, time=times, func=func, parms=parms,
                 nnz=c(nspec,rev(dimens), rev(Bnd)), sparsetype = jactype, ...)
+    else
+      out <- stodes(y=y,time=times,func=func,parms=parms,
+                    sparsetype=jactype, ...)
+
   } else {
     if (is.null(jactype))
       jactype <- "sparse"
